@@ -9,10 +9,11 @@ api = Api(bp)
 
 
 def init_app(app):
-    api.add_resource(UserResource, "/users/")
-    api.add_resource(DomainResource, "/domains/")
-    api.add_resource(StrConfigResource, "/str_configs/")
-    api.add_resource(BoolConfigResource, "/bool_configs/")
+    api.add_resource(UserResource, "/users/","/users/<uuid:uuid>")
+    api.add_resource(DomainResource, "/domains/","/domains/<string:domain>")
+    api.add_resource(ParentDomainResource, "/parent_domains/","/parent_domains/<string:domain>")
+    api.add_resource(ConfigResource, "/configs/","/configs/<string:key>/")
+    
     api.add_resource(AllResource, "/all/")
     api.add_resource(UpdateUsageResource, "/update_usage/")
     api.add_resource(HelloResource, "/hello/")
